@@ -26,27 +26,27 @@ const (
 
 var (
 	forwardSamples = prometheus.NewCounter(prometheus.CounterOpts{
-		Name: "telemeter_forward_samples_total",
-		Help: "Total amount of samples successfully forwarded",
-	})
-	forwardErrors = prometheus.NewCounter(prometheus.CounterOpts{
-		Name: "telemeter_forward_request_errors_total",
-		Help: "Total amount of errors encountered while forwarding",
+		Name: "telemeter_v1_forward_samples_total",
+		Help: "Total amount of successfully forwarded samples from v1 requests.",
 	})
+	forwardRequests = prometheus.NewCounterVec(prometheus.CounterOpts{
+		Name: "telemeter_v1_forward_requests_total",
+		Help: "Total amount of forwarded v1 requests.",
+	}, []string{"result"})
 	forwardDuration = prometheus.NewHistogramVec(prometheus.HistogramOpts{
-		Name:    "telemeter_forward_request_duration_seconds",
-		Help:    "Tracks the duration of all forwarding requests",
+		Name:    "telemeter_v1_forward_request_duration_seconds",
+		Help:    "Tracks the duration of all requests forwarded v1.",
 		Buckets: []float64{.005, .01, .025, .05, .1, .25, .5, 1, 2.5, 5}, // max = timeout
 	}, []string{"status_code"})
 	overwrittenTimestamps = prometheus.NewCounter(prometheus.CounterOpts{
-		Name: "telemeter_forward_overwritten_timestamps_total",
-		Help: "Total number of timestamps that were overwritten",
+		Name: "telemeter_v1_forward_overwritten_timestamps_total",
+		Help: "Total number of timestamps from v1 requests that were overwritten.",
 	})
 )
 
 func init() {
 	prometheus.MustRegister(forwardSamples)
-	prometheus.MustRegister(forwardErrors)
+	prometheus.MustRegister(forwardRequests)
 	prometheus.MustRegister(forwardDuration)
 	prometheus.MustRegister(overwrittenTimestamps)
 }
@@ -76,74 +76,74 @@ func (s *Store) WriteMetrics(ctx context.Context, p *store.PartitionedMetrics) e
 		return nil
 	}
 
-	go func() {
-		// Run in a func to catch all transient errors
-		err := func() error {
-			timeseries, err := convertToTimeseries(p, time.Now())
-			if err != nil {
-				return err
-			}
-
-			if len(timeseries) == 0 {
-				level.Info(s.logger).Log("msg", "no time series to forward to receive endpoint")
-				return nil
-			}
-
-			wreq := &prompb.WriteRequest{
-				Timeseries: timeseries,
-			}
-
-			data, err := proto.Marshal(wreq)
-			if err != nil {
-				return err
-			}
-
-			compressed := snappy.Encode(nil, data)
-
-			req, err := http.NewRequest(http.MethodPost, s.url.String(), bytes.NewBuffer(compressed))
-			if err != nil {
-				return err
-			}
-			req.Header.Add("THANOS-TENANT", p.PartitionKey)
-
-			ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
-			defer cancel()
-
-			req = req.WithContext(ctx)
-
-			begin := time.Now()
-			resp, err := s.client.Do(req)
-			if err != nil {
-				return err
-			}
-
-			forwardDuration.
-				WithLabelValues(fmt.Sprintf("%d", resp.StatusCode)).
-				Observe(time.Since(begin).Seconds())
-
-			meanDrift := timeseriesMeanDrift(timeseries, time.Now().Unix())
-			if math.Abs(meanDrift) > 10 {
-				level.Info(s.logger).Log("msg", "mean drift from now for clusters", "partitionkey", p.PartitionKey, "drift", fmt.Sprintf("%.3fs", meanDrift))
-			}
-
-			if resp.StatusCode/100 != 2 {
-				return fmt.Errorf("response status code is %s", resp.Status)
-			}
-
-			s := 0
-			for _, ts := range wreq.Timeseries {
-				s = s + len(ts.Samples)
-			}
-			forwardSamples.Add(float64(s))
-
-			return nil
-		}()
+	err := func() error {
+		timeseries, err := convertToTimeseries(p, time.Now())
 		if err != nil {
-			forwardErrors.Inc()
-			level.Error(s.logger).Log("msg", "forwarding error", "err", err)
+			return err
 		}
-	}()
 
+		if len(timeseries) == 0 {
+			level.Info(s.logger).Log("msg", "no time series to forward to receive endpoint")
+			return nil
+		}
+
+		wreq := &prompb.WriteRequest{
+			Timeseries: timeseries,
+		}
+
+		data, err := proto.Marshal(wreq)
+		if err != nil {
+			return err
+		}
+
+		compressed := snappy.Encode(nil, data)
+
+		req, err := http.NewRequest(http.MethodPost, s.url.String(), bytes.NewBuffer(compressed))
+		if err != nil {
+			return err
+		}
+		req.Header.Add("THANOS-TENANT", p.PartitionKey)
+
+		ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
+		defer cancel()
+
+		req = req.WithContext(ctx)
+
+		begin := time.Now()
+		resp, err := s.client.Do(req)
+		if err != nil {
+			return err
+		}
+
+		forwardDuration.
+			WithLabelValues(fmt.Sprintf("%d", resp.StatusCode)).
+			Observe(time.Since(begin).Seconds())
+
+		meanDrift := timeseriesMeanDrift(timeseries, time.Now().Unix())
+		if math.Abs(meanDrift) > 10 {
+			level.Info(s.logger).Log("msg", "mean drift from now for clusters", "partitionkey", p.PartitionKey, "drift", fmt.Sprintf("%.3fs", meanDrift))
+		}
+
+		if resp.StatusCode/100 != 2 {
+			return fmt.Errorf("response status code is %s", resp.Status)
+		}
+
+		s := 0
+		for _, ts := range wreq.Timeseries {
+			s = s + len(ts.Samples)
+		}
+		forwardSamples.Add(float64(s))
+
+		return nil
+	}()
+	if err != nil {
+		forwardRequests.WithLabelValues("error").Inc()
+		level.Error(s.logger).Log("msg", "forwarding error", "err", err)
+
+		return err
+	}
+
+	forwardRequests.WithLabelValues("success").Inc()
 	return s.next.WriteMetrics(ctx, p)
 }
 
